@@ -1,14 +1,14 @@
-# Copyrights 2007-2018 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2007-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
+# Pod stripped from pm file by OODoc 2.03.
 # This code is part of distribution Log-Report-Lexicon. Meta-POD processed
 # with OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
-package Log::Report::Lexicon::POTcompact;
-use vars '$VERSION';
-$VERSION = '1.11';
+package Log::Report::Lexicon::POTcompact;{
+our $VERSION = '1.12';
+}
 
 use base 'Log::Report::Lexicon::Table';
 
@@ -62,7 +62,7 @@ sub read($@)
                     , charset => $charset, fn => $fn;
 
            trace "auto-detected charset $charset for $fn";
-           $fh->binmode(":encoding($charset):crlf");
+           binmode $fh, ":encoding($charset):crlf";
 
            $_ = $enc->decode($_) for @msgstr, $msgctxt;
        }
